@@ -138,8 +138,8 @@ integrandSurface <- function(
     proj_xz = TRUE,
     proj_beta = FALSE, # bug with my latest hyperframe !!!
     n = 501L,
-    newid = min(5L, .row_names_info(newdata, type = 2L)) |> seq_len(), 
-    qlim = range(X, newX),
+    newid = min(3L, .row_names_info(newdata, type = 2L)) |> seq_len(), 
+    qlim = range(X[is.finite(X)], newX[is.finite(newX)]), # removing NA, NaN, Inf
     axis_col = c('dodgerblue', 'deeppink', 'darkolivegreen'),
     beta_col = 'purple',
     surface_col = 
